from PIL import Image, ImageEnhance
import cv2
import numpy as np
import argparse

def enhance_image(input_image_path, output_image_path, brightness=1.2, contrast=1.3, sharpness=2.0):
    try:
        img = Image.open(input_image_path)
        
        enhancer = ImageEnhance.Brightness(img)
        img = enhancer.enhance(brightness)
        
        enhancer = ImageEnhance.Contrast(img)
        img = enhancer.enhance(contrast)
        
        enhancer = ImageEnhance.Sharpness(img)
        img = enhancer.enhance(sharpness)
        
        img_cv = np.array(img)
        img_cv = cv2.cvtColor(img_cv, cv2.COLOR_RGB2BGR)
        
        denoised_img = cv2.fastNlMeansDenoisingColored(img_cv, None, 10, 10, 7, 21)
        
        cv2.imwrite(output_image_path, denoised_img)
        print(f'Image is save in {output_image_path}')
    except FileNotFoundError:
        print(f"File {input_image_path} not found")
    except Exception as e:
        print(f"Error: {e}")

def main():
    parser = argparse.ArgumentParser(description='Enhance an image and save the result.')
    parser.add_argument('input_image', type=str, help='Path to the input image')
    parser.add_argument('output_image', type=str, help='Path to the output image')
    parser.add_argument('--brightness', type=float, default=1.2, help='Brightness factor')
    parser.add_argument('--contrast', type=float, default=1.3, help='Contrast factor')
    parser.add_argument('--sharpness', type=float, default=2.0, help='Sharpness factor')
    
    args = parser.parse_args()
    
    enhance_image(args.input_image, args.output_image, args.brightness, args.contrast, args.sharpness)


from setuptools import setup, find_packages

setup(
    name='imgboost',
    version='0.1.0',
    description='A package to enhance images with brightness, contrast, and sharpness adjustments.',
    author='Dione Alfarisi',
    author_email='ardionefarisi1322@gmail.com',
    url='https://github.com/dionealfarisi/imgboost',
    packages=find_packages(),
    install_requires=[
        'Pillow',
        'opencv-python',
        'numpy'
    ],
    entry_points={
        'console_scripts': [
            'boost=imgboost.enhance:main',
        ],
    },
)


import unittest
import os
from PIL import Image
from imgboost.enhance import enhance_image

class TestEnhanceImage(unittest.TestCase):

    def setUp(self):
        self.input_image = 'test_input.jpg'
        self.output_image = 'test_output.jpg'
        
        img = Image.new('RGB', (100, 100), color='red')
        img.save(self.input_image)

    def test_enhance_image(self):
        enhance_image(self.input_image, self.output_image, brightness=1.5, contrast=1.4, sharpness=1.8)
        
        self.assertTrue(os.path.exists(self.output_image))
        
        with Image.open(self.output_image) as img:
            self.assertGreater(img.size[0], 0)
            self.assertGreater(img.size[1], 0)

    def tearDown(self):
        if os.path.exists(self.input_image):
            os.remove(self.input_image)
        if os.path.exists(self.output_image):
            os.remove(self.output_image)

if __name__ == '__main__':
    unittest.main()